@@ -24,7 +24,7 @@ Example usage:
 >>> import uinput
 >>> driver = uinput.Driver()
 >>> driver.move_pointer(100, 100)
->>> driver.click(uinput.codes.BTN_LEFT)
+>>> driver.click(uinput.keycodes.BTN_LEFT)
 """
 
 import _suinput
@@ -47,23 +47,24 @@ from _suinput import BUS_HOST
 from _suinput import BUS_GSC
 from _suinput import BUS_ATARI
 
-import codes
+import keycodes
 
 __all__ = [
     "Driver",
     ]
 
 class Driver(object):
-
     """Device driver for the Linux uinput-system.
 
+    keycodes are defined in uinput.keycodes -module.
+
     For the documentation of the constructor arguments, see the
     documentation of the corresponding properties.
     """
 
     def __init__(self, name="python-uinput", bustype=_suinput.BUS_VIRTUAL,
                  vendor=0, product=0, version=0):
-        self._input_fd = _suinput.open(name, bustype, vendor, product, version)
+        self._context = _suinput.open(name, bustype, vendor, product, version)
         self._name = name
         self._bustype = bustype
         self._vendor = vendor
@@ -72,65 +73,59 @@ class Driver(object):
 
     @property
     def name(self):
-        "Kernel name of the device."
+        "Name of the device."
         return self._name
 
     @property
     def bustype(self):
-        """Bustype of the device.
-        Must be one of the BUS_ -prefixed constant values.
+        """One of the BUS_ -prefixed constant values.
         """
         return self._bustype
 
     @property
     def vendor(self):
-        """Vendor number of the device."""
+        """Arbitrary 16 bit unsigned integer vendor id."""
         return self._vendor
 
     @property
     def product(self):
-        """Product number of the device."""
+        """Arbitrary 16 bit unsigned integer product id."""
         return self._product
 
     @property
     def version(self):
-        """Version number of the device."""
+        """Arbitrary 16 bit unsigned integer version number."""
         return self._version
 
     def move_pointer(self, x, y):
-        """Sends a relative pointer motion event to the event device.
-        Values increase towards right-bottom.
-        """
-        _suinput.move_pointer(self._input_fd, x, y)
+        "Move pointer towards bottom-right."
+        _suinput.move_pointer(self._context, x, y)
 
-    def press(self, uinput_code):
-        """Sends a press event to the event device. Event is repeated after
-        a short delay until a release event is sent.
+    def press(self, keycode):
+        """Send a press event.
+        Event is repeated after a short delay until a release event is sent."""
+        _suinput.press(self._context, keycode)
 
-        `uinput_code` must be one of the constant values defined in
-        uinput.codes -module.
-        """
-        _suinput.press(self._input_fd, uinput_code)
+    def release(self, keycode):
+        "Send a release event."
+        _suinput.release(self._context, keycode)
 
-    def release(self, uinput_code):
-        """Sends a release event to the event device.
+    def click(self, keycode):
+        "Send a press and a release event."
+        _suinput.click(self._context, keycode)
 
-        `uinput_code` must be one of the constant values defined in
-        uinput.codes -module.
-        """
-        _suinput.release(self._input_fd, uinput_code)
+    def press_release(self, signed_keycode):
+        """Send a press event if signed_keycode > 0, otherwise send
+        a release event."""
+        _suinput.press_release(self._context, signed_keycode)
 
-    def click(self, uinput_code):
-        """Sends a press and release events to the event device.
+    def toggle(self, keycode):
+        "Press button if it is not pressed currently, release it otherwise."
+        _suinput.toggle(self._context, keycode)
 
-        `uinput_code` must be one of the constant values defined in
-        uinput.codes -module.
-
-        This method is provided as a convenience and has effectively the
-        same result as calling press(uinput_fd) and release(uinput_fd)
-        sequentially.
-        """
-        _suinput.click(self._input_fd, uinput_code)
+    def is_pressed(self, keycode):
+        "Return True if button is pressed, otherwise return False."
+        return _suinput.is_pressed(self._context, keycode)
 
     def __del__(self):
-        _suinput.close(self._input_fd)
+        _suinput.close(self._context)
